protoadapt

package
v0.0.0-...-bb96f36 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2023 License: BSD-3-Clause Imports: 3 Imported by: 0

Documentation

Overview

Package protoadapt bridges the original and new proto APIs.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MessageV1Of

func MessageV1Of(m MessageV2) protoiface.MessageV1

MessageV1Of converts a v2 message to a v1 message. It returns nil if m is nil.

func MessageV2Of

func MessageV2Of(m MessageV1) proto.Message

MessageV2Of converts a v1 message to a v2 message. It returns nil if m is nil.

Types

type MessageV1

type MessageV1 = protoiface.MessageV1

MessageV1 is the original "github.com/golang/protobuf/proto".Message type.

type MessageV2

type MessageV2 = proto.Message

MessageV2 is the Message type used by the current e.coding.net/nb-shenyang/byn/protobuf-go module, adding support for reflection.

Source Files

  • convert.go

Jump to